@@ -21,49 +21,32 @@
  *                                                                         *
  ***************************************************************************/
 
-// include files for QT
-#include <QtCore/QDir>
-#include <QtCore/QPointer>
-#include <QtGui/QPrintDialog>
-#include <QtGui/QPainter>
-#include <QtGui/QLayout>
-#include <QtGui/QClipboard>
-#include <QtGui/QContextMenuEvent>
-#include <QtGui/QPixmap>
-#include <QtGui/QDesktopWidget>
+// include files for Qt
+#include <QApplication>
+#include <QClipboard>
+#include <QDebug>
+#include <QDesktopWidget>
+#include <QFileDialog>
+#include <QImageWriter>
+#include <QMenuBar>
+#include <QPainter>
+#include <QPrintDialog>
+#include <QTemporaryFile>
 
-// include files for KDE
-#include <kxmlguiclient.h>
-#include <ktoolbar.h>
-#include <ktoggleaction.h>
-#include <kactioncollection.h>
-#include <kselectaction.h>
-#include <kdeversion.h>
-#include <kxmlguifactory.h>
-#include <kicon.h>
-#include <kapplication.h>
-#include <kstandardshortcut.h>
-#include <kshortcutsdialog.h>
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kmenubar.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kstandardaction.h>
-#include <khelpmenu.h>
-#include <kimageio.h>
-#include <kio/job.h>
-#include <kio/netaccess.h>
-#include <ktemporaryfile.h>
-#include <kmenu.h>
-#include <kedittoolbar.h>
-#include <kglobal.h>
-#include <kdeprintdialog.h>
+// include files for KF5
+#include <KActionCollection>
+#include <KConfigGroup>
+#include <KEditToolBar>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSelectAction>
+#include <KShortcutsDialog>
+#include <KToggleAction>
+#include <KXMLGUIFactory>
+#include <KIO/FileCopyJob>
 
 // application specific includes
-#include "kmag.moc"
+#include "kmag.h"
 #include "kmagzoomview.h"
 #include "kmagselrect.h"
 
@@ -74,10 +57,10 @@ KmagApp::KmagApp(QWidget* , const char* name)
 {
   setObjectName( QLatin1String( name ) );
   setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
-  config=KGlobal::config();
+  config=KSharedConfig::openConfig();
 
-  zoomArrayString << QLatin1String( "5:1" ) << QLatin1String( "2:1" ) << QLatin1String( "1:1" ) << QLatin1String( "1:1.5" ) << QLatin1String( "1:2" ) << QLatin1String( "1:3" ) << QLatin1String( "1:4" ) << QLatin1String( "1:5" )
-    << QLatin1String( "1:6" ) << QLatin1String( "1:7" ) << QLatin1String( "1:8" ) << QLatin1String( "1:12" ) << QLatin1String( "1:16" ) << QLatin1String( "1:20" );
+  zoomArrayString << QStringLiteral( "5:1" ) << QStringLiteral( "2:1" ) << QStringLiteral( "1:1" ) << QStringLiteral( "1:1.5" ) << QStringLiteral( "1:2" ) << QStringLiteral( "1:3" ) << QStringLiteral( "1:4" ) << QStringLiteral( "1:5" )
+    << QStringLiteral( "1:6" ) << QStringLiteral( "1:7" ) << QStringLiteral( "1:8" ) << QStringLiteral( "1:12" ) << QStringLiteral( "1:16" ) << QStringLiteral( "1:20" );
 
   zoomArray << 0.2 <<0.5 << 1.0;
   zoomArray << 1.5 << 2.0 << 3.0;
@@ -134,28 +117,28 @@ KmagApp::~KmagApp()
 
 void KmagApp::initActions()
 {
-  fileNewWindow = actionCollection()->addAction(QLatin1String( "new_window" ));
-  fileNewWindow->setIcon(KIcon(QLatin1String( "window-new" )));
+  fileNewWindow = actionCollection()->addAction(QStringLiteral( "new_window" ));
+  fileNewWindow->setIcon(QIcon::fromTheme(QStringLiteral( "window-new" )));
   fileNewWindow->setText(i18n("New &Window"));
-  connect(fileNewWindow, SIGNAL(triggered(bool)), SLOT(slotFileNewWindow()));
-  fileNewWindow->setShortcuts(KStandardShortcut::openNew());
+  connect(fileNewWindow, &QAction::triggered, this, &KmagApp::slotFileNewWindow);
+  actionCollection()->setDefaultShortcuts(fileNewWindow, KStandardShortcut::openNew());
   fileNewWindow->setToolTip(i18n("Open a new KMagnifier window"));
 
-  refreshSwitch = actionCollection()->addAction(QLatin1String( "start_stop_refresh" ));
-  refreshSwitch->setIcon(KIcon(QLatin1String( "process-stop" )));
+  refreshSwitch = actionCollection()->addAction(QStringLiteral( "start_stop_refresh" ));
+  refreshSwitch->setIcon(QIcon::fromTheme(QStringLiteral( "process-stop" )));
   refreshSwitch->setText(i18n("&Stop"));
-  connect(refreshSwitch, SIGNAL(triggered(bool)), SLOT(slotToggleRefresh()));
-  refreshSwitch->setShortcuts(KStandardShortcut::reload());
+  connect(refreshSwitch, &QAction::triggered, this, &KmagApp::slotToggleRefresh);
+  actionCollection()->setDefaultShortcuts(refreshSwitch, KStandardShortcut::reload());
   refreshSwitch->setToolTip(i18n("Click to stop window refresh"));
   refreshSwitch->setWhatsThis(i18n("Clicking on this icon will <b>start</b> / <b>stop</b> "
                                    "updating of the display. Stopping the update will zero the processing power "
                                    "required (CPU usage)"));
 
-  m_pSnapshot = actionCollection()->addAction(QLatin1String( "snapshot" ));
-  m_pSnapshot->setIcon(KIcon(QLatin1String( "ksnapshot" )));
+  m_pSnapshot = actionCollection()->addAction(QStringLiteral( "snapshot" ));
+  m_pSnapshot->setIcon(QIcon::fromTheme(QStringLiteral( "ksnapshot" )));
   m_pSnapshot->setText(i18n("&Save Snapshot As..."));
-  connect(m_pSnapshot, SIGNAL(triggered(bool)), SLOT(saveZoomPixmap()));
-  m_pSnapshot->setShortcuts(KStandardShortcut::save());
+  connect(m_pSnapshot, &QAction::triggered, this, &KmagApp::saveZoomPixmap);
+  actionCollection()->setDefaultShortcuts(m_pSnapshot, KStandardShortcut::save());
   m_pSnapshot->setWhatsThis(i18n("Saves the zoomed view to an image file."));
   m_pSnapshot->setToolTip(i18n("Save image to a file"));
 
@@ -174,62 +157,62 @@ void KmagApp::initActions()
 
   setStandardToolBarMenuEnabled(true);
 
-  m_modeFollowMouse = new KToggleAction(KIcon(QLatin1String( "followmouse" )), i18n("&Follow Mouse Mode"), this);
-  actionCollection()->addAction(QLatin1String( "mode_followmouse" ), m_modeFollowMouse);
-  connect(m_modeFollowMouse, SIGNAL(triggered(bool)), SLOT(slotModeChanged()));
-  m_modeFollowMouse->setShortcut(Qt::Key_F2);
+  m_modeFollowMouse = new KToggleAction(QIcon::fromTheme(QStringLiteral( "followmouse" )), i18n("&Follow Mouse Mode"), this);
+  actionCollection()->addAction(QStringLiteral( "mode_followmouse" ), m_modeFollowMouse);
+  connect(m_modeFollowMouse, &QAction::triggered, this, &KmagApp::slotModeChanged);
+  actionCollection()->setDefaultShortcut(m_modeFollowMouse, Qt::Key_F2);
   m_modeFollowMouse->setIconText(i18n("Mouse"));
   m_modeFollowMouse->setToolTip(i18n("Magnify around the mouse cursor"));
   m_modeFollowMouse->setWhatsThis(i18n("If selected, the area around the mouse cursor is magnified"));
 
 #ifdef QAccessibilityClient_FOUND
 
-  m_modeFollowFocus = new KToggleAction(KIcon(QLatin1String( "view-restore" )), i18n("&Follow Focus Mode"), this);
+  m_modeFollowFocus = new KToggleAction(QIcon::fromTheme(QLatin1String( "view-restore" )), i18n("&Follow Focus Mode"), this);
   actionCollection()->addAction(QLatin1String( "mode_followfocus" ), m_modeFollowFocus);
   connect(m_modeFollowFocus, SIGNAL(triggered(bool)), SLOT(slotModeChanged()));
-  m_modeFollowFocus->setShortcut(Qt::Key_F2);
+  actionCollection()->setDefaultShortcut(m_modeFollowFocus, Qt::Key_F2);
   m_modeFollowFocus->setIconText(i18n("Focus"));
   m_modeFollowFocus->setToolTip(i18n("Magnify around the keyboard focus"));
   m_modeFollowFocus->setWhatsThis(i18n("If selected, the area around the keyboard cursor is magnified"));
 
 #endif
 
-  m_modeSelWin = new KToggleAction(KIcon(QLatin1String( "window" )), i18n("Se&lection Window Mode"), this);
-  actionCollection()->addAction(QLatin1String( "mode_selectionwindow" ), m_modeSelWin);
-  connect(m_modeSelWin, SIGNAL(triggered(bool)), SLOT(slotModeSelWin()));
-  m_modeSelWin->setShortcut(Qt::Key_F3);
+  m_modeSelWin = new KToggleAction(QIcon::fromTheme(QStringLiteral( "window" )), i18n("Se&lection Window Mode"), this);
+  actionCollection()->addAction(QStringLiteral( "mode_selectionwindow" ), m_modeSelWin);
+  connect(m_modeSelWin, &QAction::triggered, this, &KmagApp::slotModeSelWin);
+  actionCollection()->setDefaultShortcut(m_modeSelWin, Qt::Key_F3);
   m_modeSelWin->setIconText(i18n("Window"));
   m_modeSelWin->setToolTip(i18n("Show a window for selecting the magnified area"));
 
-  m_modeWholeScreen = new KToggleAction(KIcon(QLatin1String( "view-fullscreen" )), i18n("&Whole Screen Mode"), this);
-  actionCollection()->addAction(QLatin1String( "mode_wholescreen" ), m_modeWholeScreen);
-  connect(m_modeWholeScreen, SIGNAL(triggered(bool)), SLOT(slotModeWholeScreen()));
-  m_modeWholeScreen->setShortcut(Qt::Key_F4);
+  m_modeWholeScreen = new KToggleAction(QIcon::fromTheme(QStringLiteral( "view-fullscreen" )), i18n("&Whole Screen Mode"), this);
+  actionCollection()->addAction(QStringLiteral( "mode_wholescreen" ), m_modeWholeScreen);
+  connect(m_modeWholeScreen, &QAction::triggered, this, &KmagApp::slotModeWholeScreen);
+  actionCollection()->setDefaultShortcut(m_modeWholeScreen, Qt::Key_F4);
   m_modeWholeScreen->setIconText(i18n("Screen"));
   m_modeWholeScreen->setToolTip(i18n("Magnify the whole screen"));
   m_modeWholeScreen->setWhatsThis(i18n("Click on this button to fit the zoom view to the zoom window."));
 
-  m_hideCursor = new KToggleAction(KIcon(QLatin1String( "hidemouse" )), i18n("Hide Mouse &Cursor"), this);
-  actionCollection()->addAction(QLatin1String( "hidecursor" ), m_hideCursor);
-  connect(m_hideCursor, SIGNAL(triggered(bool)), SLOT(slotToggleHideCursor()));
-  m_hideCursor->setShortcut(Qt::Key_F6);
+  m_hideCursor = new KToggleAction(QIcon::fromTheme(QStringLiteral( "hidemouse" )), i18n("Hide Mouse &Cursor"), this);
+  actionCollection()->addAction(QStringLiteral( "hidecursor" ), m_hideCursor);
+  connect(m_hideCursor, &QAction::triggered, this, &KmagApp::slotToggleHideCursor);
+  actionCollection()->setDefaultShortcut(m_hideCursor, Qt::Key_F6);
   #ifdef havesetCheckedStatef
   m_hideCursor->setCheckedState(KGuiItem(i18n("Show Mouse &Cursor")));
   #endif
   m_hideCursor->setIconText(i18n("Hide"));
   m_hideCursor->setToolTip(i18n("Hide the mouse cursor"));
 
-  m_staysOnTop = new KToggleAction(KIcon(QLatin1String( "go-top" )), i18n("Stays On Top"), this);
-  actionCollection()->addAction(QLatin1String( "staysontop" ), m_staysOnTop);
-  connect(m_staysOnTop, SIGNAL(triggered(bool)), SLOT(slotStaysOnTop()));
-  m_staysOnTop->setShortcut(Qt::Key_F7);
+  m_staysOnTop = new KToggleAction(QIcon::fromTheme(QStringLiteral( "go-top" )), i18n("Stays On Top"), this);
+  actionCollection()->addAction(QStringLiteral( "staysontop" ), m_staysOnTop);
+  connect(m_staysOnTop, &QAction::triggered, this, &KmagApp::slotStaysOnTop);
+  actionCollection()->setDefaultShortcut(m_staysOnTop, Qt::Key_F7);
   m_staysOnTop->setToolTip(i18n("The KMagnifier Window stays on top of other windows."));
 
   m_pZoomIn = actionCollection()->addAction(KStandardAction::ZoomIn, this, SLOT(zoomIn()));
   m_pZoomIn->setWhatsThis(i18n("Click on this button to <b>zoom-in</b> on the selected region."));
 
   m_pZoomBox = new KSelectAction(i18n("&Zoom"), this);
-  actionCollection()->addAction(QLatin1String( "zoom" ), m_pZoomBox);
+  actionCollection()->addAction(QStringLiteral( "zoom" ), m_pZoomBox);
   m_pZoomBox->setItems(zoomArrayString);
   m_pZoomBox->setWhatsThis(i18n("Select the zoom factor."));
   m_pZoomBox->setToolTip(i18n("Zoom factor"));
@@ -238,24 +221,22 @@ void KmagApp::initActions()
   m_pZoomOut->setWhatsThis(i18n("Click on this button to <b>zoom-out</b> on the selected region."));
 
   m_pRotationBox = new KSelectAction(i18n("&Rotation"),this);
-  actionCollection()->addAction(QLatin1String( "rotation" ), m_pRotationBox);
+  actionCollection()->addAction(QStringLiteral( "rotation" ), m_pRotationBox);
   m_pRotationBox->setItems(rotationArrayString);
   m_pRotationBox->setWhatsThis(i18n("Select the rotation degree."));
   m_pRotationBox->setToolTip(i18n("Rotation degree"));
 
-  // KHelpMenu *newHelpMenu = new KHelpMenu(this, KGlobal::mainComponent().aboutData());
-
   m_keyConf = actionCollection()->addAction(KStandardAction::KeyBindings, this, SLOT(slotConfKeys()));
   m_toolConf = actionCollection()->addAction(KStandardAction::ConfigureToolbars, this, SLOT(slotEditToolbars()));
 
   m_pFPSBox = new KSelectAction(i18n("&Refresh"),this);
-  actionCollection()->addAction(QLatin1String( "fps_selector" ), m_pFPSBox);
+  actionCollection()->addAction(QStringLiteral( "fps_selector" ), m_pFPSBox);
   m_pFPSBox->setItems(fpsArrayString);
   m_pFPSBox->setWhatsThis(i18n("Select the refresh rate. The higher the rate, the more computing power (CPU) will be needed."));
   m_pFPSBox->setToolTip(i18n("Refresh rate"));
 
   m_pColorBox = new KSelectAction(i18nc("Color-blindness simulation mode", "&Color"),this);
-  actionCollection()->addAction(QLatin1String( "color_mode" ), m_pColorBox);
+  actionCollection()->addAction(QStringLiteral( "color_mode" ), m_pColorBox);
   m_pColorBox->setItems(colorArrayString);
   m_pColorBox->setWhatsThis(i18n("Select a mode to simulate various types of color-blindness."));
   m_pColorBox->setToolTip(i18n("Color-blindness Simulation Mode"));
@@ -299,16 +280,16 @@ void KmagApp::slotChangeColorIndex(int index)
 void KmagApp::initConnections()
 {
   // change in zoom value -> update the view
-  connect(this, SIGNAL(updateZoomValue(float)), m_zoomView, SLOT(setZoom(float)));
-  connect(this, SIGNAL(updateRotationValue(int)), m_zoomView, SLOT(setRotation(int)));
-  connect(this, SIGNAL(updateFPSValue(float)), m_zoomView, SLOT(setRefreshRate(float)));
-  connect(this, SIGNAL(updateColorValue(int)), m_zoomView, SLOT(setColorMode(int)));
+  connect(this, &KmagApp::updateZoomValue, m_zoomView, &KMagZoomView::setZoom);
+  connect(this, &KmagApp::updateRotationValue, m_zoomView, &KMagZoomView::setRotation);
+  connect(this, &KmagApp::updateFPSValue, m_zoomView, &KMagZoomView::setRefreshRate);
+  connect(this, &KmagApp::updateColorValue, m_zoomView, &KMagZoomView::setColorMode);
 
   // change in zoom index -> update the selector
-  connect(this, SIGNAL(updateZoomIndex(int)), this, SLOT(slotChangeZoomBoxIndex(int)));
-  connect(this, SIGNAL(updateRotationIndex(int)), this, SLOT(slotChangeRotationBoxIndex(int)));
-  connect(this, SIGNAL(updateFPSIndex(int)), this, SLOT(slotChangeFPSIndex(int)));
-  connect(this, SIGNAL(updateColorIndex(int)), this, SLOT(slotChangeColorIndex(int)));
+  connect(this, &KmagApp::updateZoomIndex, this, &KmagApp::slotChangeZoomBoxIndex);
+  connect(this, &KmagApp::updateRotationIndex, this, &KmagApp::slotChangeRotationBoxIndex);
+  connect(this, &KmagApp::updateFPSIndex, this, &KmagApp::slotChangeFPSIndex);
+  connect(this, &KmagApp::updateColorIndex, this, &KmagApp::slotChangeColorIndex);
 
   // selector selects a zoom index -> set the zoom index
   connect(m_pZoomBox, SIGNAL(triggered(int)), this, SLOT(setZoomIndex(int)));
@@ -385,7 +366,7 @@ void KmagApp::readOptions()
   unsigned int colorIndex = cg.readEntry("ColorIndex", 0);
   setColorIndex(colorIndex);
   emit updateColorIndex(colorIndex);
-/*
+
   QString mode = cg.readEntry("Mode", "followmouse");
   if (mode == QLatin1String( "wholescreen" )) {
     slotModeWholeScreen();
@@ -398,7 +379,7 @@ void KmagApp::readOptions()
     m_modeFollowMouse->setChecked(true);
     slotModeChanged();
   }
-*/
+
   QRect defaultRect(0,0,211,164);
   m_zoomView->setSelRectPos(cg.readEntry("SelRect", defaultRect));
 
@@ -428,7 +409,7 @@ void KmagApp::contextMenuEvent ( QContextMenuEvent * e )
 {
  // show popup
  KXMLGUIFactory *factory = this->factory();
- QMenu *popup = (QMenu *)factory->container(QLatin1String( "mainPopUp" ),this);
+ QMenu *popup = (QMenu *)factory->container(QStringLiteral( "mainPopUp" ),this);
  if (popup != 0)
    popup->popup(e->globalPos());
  e->accept();
@@ -481,7 +462,7 @@ void KmagApp::setZoomIndex(int index)
 {
   if(index < 0 || index >= (int)zoomArray.size()) {
     // the index is invalid
-    kWarning() << "Invalid index!" ;
+    qDebug() << "Invalid index!" ;
     return;
   } else if((int)m_zoomIndex == index) {
     // do nothing!
@@ -517,7 +498,7 @@ void KmagApp::setRotationIndex(int index)
 {
   if(index < 0 || index >= (int)rotationArray.size()) {
     // the index is invalid
-    kWarning() << "Invalid index!" ;
+    qDebug() << "Invalid index!" ;
     return;
   } else if((int)m_rotationIndex == index) {
     // do nothing!
@@ -537,7 +518,7 @@ void KmagApp::setFPSIndex(int index)
 {
   if(index < 0 || index >= (int)fpsArray.size()) {
     // the index is invalid
-    kWarning() << "Invalid index!" ;
+    qDebug() << "Invalid index!" ;
     return;
   } else if((int)m_fpsIndex == index) {
     // do nothing!
@@ -557,7 +538,7 @@ void KmagApp::setColorIndex(int index)
 {
   if(index < 0 || index >= (int)colorArray.size()) {
     // the index is invalid
-    kWarning() << "Invalid index!" ;
+    qDebug() << "Invalid index!" ;
     return;
   } else if((int)m_colorIndex == index) {
     // do nothing!
@@ -583,40 +564,47 @@ void KmagApp::saveZoomPixmap()
     toggled = true;
   }
 
-  KUrl url = KFileDialog::getSaveUrl(QString(),
-              KImageIO::pattern(KImageIO::Writing),
-             0,i18n("Save Snapshot As"));
+  QStringList mimeTypes;
+  QList<QByteArray> supported = QImageWriter::supportedMimeTypes();
+  foreach (QByteArray mimeType, supported) {
+    mimeTypes.append(QString::fromLatin1(mimeType));
+  }
+
+  QFileDialog fileDialog(this);
+  fileDialog.setWindowTitle(i18n("Save Snapshot As"));
+  fileDialog.setAcceptMode(QFileDialog::AcceptSave);
+  fileDialog.setDefaultSuffix(QStringLiteral("png"));
+  fileDialog.setMimeTypeFilters(mimeTypes);
+  QUrl url;
+  if (fileDialog.exec() && !fileDialog.selectedUrls().isEmpty()) {
+      url = fileDialog.selectedUrls().at(0);
+  }
 
   if(!url.fileName().isEmpty()) {
     if(!url.isLocalFile()) {
       // create a temp file.. save image to it.. copy over the n/w and then delete the temp file.
-      KTemporaryFile tempFile;
-#ifdef __GNUC__
-#warning "kde4: port KImageIO::type \n";
-#endif
-      if(!tempFile.open() || !m_zoomView->getImage().save(tempFile.fileName(),"png"/*, KImageIO::type(url.fileName()).latin1()*/)) {
+      QTemporaryFile tempFile;
+      if(!tempFile.open() || !m_zoomView->getImage().save(tempFile.fileName())) {
         KMessageBox::error(0, i18n("Unable to save temporary file (before uploading to the network file you specified)."),
                           i18n("Error Writing File"));
       } else {
-        if(!KIO::NetAccess::upload(tempFile.fileName(), url, this)) {
+        KIO::FileCopyJob *job = KIO::file_copy(QUrl::fromLocalFile(tempFile.fileName()), url);
+        if(!job) {
           KMessageBox::error(0, i18n("Unable to upload file over the network."),
                             i18n("Error Writing File"));
         } else {
-          KMessageBox::information(0, i18n("Current zoomed image saved to\n%1", url.prettyUrl()),
-                              i18n("Information"), QLatin1String( "save_confirm" ));
+          KMessageBox::information(0, i18n("Current zoomed image saved to\n%1", url.toDisplayString()),
+                              i18n("Information"), QStringLiteral( "save_confirm" ));
         }
       }
 
     } else {
-#ifdef __GNUC__
-#warning "kde4 : port KImageIO::type(...) \n";
-#endif
-      if(!m_zoomView->getImage().save(url.path(), "png"/*KImageIO::type(url.fileName()).latin1()*/)) {
+      if(!m_zoomView->getImage().save(url.path())) {
         KMessageBox::error(0, i18n("Unable to save file. Please check if you have permission to write to the directory."),
                             i18n("Error Writing File"));
       } else {
-        KMessageBox::information(0, i18n("Current zoomed image saved to\n%1", url.prettyUrl()),
-                                i18n("Information"), QLatin1String( "save_confirm" ));
+        KMessageBox::information(0, i18n("Current zoomed image saved to\n%1", url.toDisplayString()),
+                                i18n("Information"), QStringLiteral( "save_confirm" ));
       }
     }
   }
@@ -630,11 +618,11 @@ void KmagApp::slotToggleRefresh()
 {
   m_zoomView->toggleRefresh();
   if(m_zoomView->getRefreshStatus()) {
-    refreshSwitch->setIcon(KIcon(QLatin1String( "process-stop" )));
+    refreshSwitch->setIcon(QIcon::fromTheme(QStringLiteral( "process-stop" )));
     refreshSwitch->setText(i18n("Stop"));
     refreshSwitch->setToolTip(i18n("Click to stop window update"));
   } else {
-    refreshSwitch->setIcon(KIcon(QLatin1String( "system-run" )));
+    refreshSwitch->setIcon(QIcon::fromTheme(QStringLiteral( "system-run" )));
     refreshSwitch->setText(i18nc("Start updating the window", "Start"));
     refreshSwitch->setToolTip(i18n("Click to start window update"));
   }
@@ -771,7 +759,7 @@ void KmagApp::slotFilePrint()
     m_printer->setOrientation(QPrinter::Portrait);
   }
 
-  QPrintDialog *printDialog = KdePrint::createPrintDialog(m_printer, this);
+  QPrintDialog *printDialog = new QPrintDialog(m_printer, this);
 
   if (printDialog->exec()) {
     QPainter paint;
@@ -819,7 +807,7 @@ void KmagApp::slotFileQuit()
 
 void KmagApp::copyToClipBoard()
 {
-  QClipboard *cb=KApplication::clipboard();
+  QClipboard *cb=QApplication::clipboard();
   cb->setPixmap(QPixmap::fromImage(m_zoomView->getImage()));
 }
 
@@ -844,10 +832,10 @@ void KmagApp::slotConfKeys()
 
 void KmagApp::slotEditToolbars()
 {
-  KConfigGroup cg( KGlobal::config(), "MainWindow" );
+  KConfigGroup cg( KSharedConfig::openConfig(), "MainWindow" );
   saveMainWindowSettings( cg );
   QPointer<KEditToolBar> dlg = new KEditToolBar( actionCollection() );
-  connect(dlg, SIGNAL(newToolBarConfig()), this, SLOT(slotNewToolbarConfig()) );
+  connect(dlg.data(), &KEditToolBar::newToolBarConfig, this, &KmagApp::slotNewToolbarConfig );
   if ( dlg->exec() )
     createGUI();
   delete dlg;
@@ -856,6 +844,6 @@ void KmagApp::slotEditToolbars()
 
 void KmagApp::slotNewToolbarConfig()
 {
-  applyMainWindowSettings( KGlobal::config()->group( "MainWindow" ) );
+  applyMainWindowSettings( KSharedConfig::openConfig()->group( "MainWindow" ) );
   createGUI();
 }
